@@ -1,8 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
@@ -18,10 +17,10 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
-**     the names of its contributors may be used to endorse or promote
-**     products derived from this software without specific prior written
-**     permission.
+**   * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
+**     of its contributors may be used to endorse or promote products derived
+**     from this software without specific prior written permission.
+**
 **
 ** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 ** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -34,6 +33,7 @@
 ** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 ** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 ** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
+**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -44,15 +44,14 @@
  * Part of the KDE project
  */
 
-#include <qpainter.h>
-//Added by qt3to4:
+#include <QPainter>
 #include <QResizeEvent>
-#include <Q3Frame>
+#include <QFrame>
+#include <QColorGroup>
 #include "ledmeter.h"
 
-KALedMeter::KALedMeter( QWidget *parent ) : Q3Frame( parent )
+KALedMeter::KALedMeter( QWidget *parent ) : QFrame( parent )
 {
-    mCRanges.setAutoDelete( TRUE );
     mRange = 100;
     mCount = 20;
     mCurrentCount = 0;
@@ -60,6 +59,13 @@ KALedMeter::KALedMeter( QWidget *parent ) : Q3Frame( parent )
     setMinimumWidth( mCount * 2 + frameWidth() );
 }
 
+KALedMeter::~KALedMeter()
+{
+    qDeleteAll(mCRanges);
+    mCRanges.clear();
+}
+
+
 void KALedMeter::setRange( int r )
 {
     mRange = r;
@@ -106,27 +112,30 @@ void KALedMeter::addColorRange( int pc, const QColor &c )
 
 void KALedMeter::resizeEvent( QResizeEvent *e )
 {
-    Q3Frame::resizeEvent( e );
+    QFrame::resizeEvent( e );
     int w = ( width() - frameWidth() - 2 ) / mCount * mCount;
     w += frameWidth() + 2;
     setFrameRect( QRect( 0, 0, w, height() ) );
 }
 
-void KALedMeter::drawContents( QPainter *p )
+void KALedMeter::paintEvent(QPaintEvent *event)
 {
+    QFrame::paintEvent(event);
+
     QRect b = contentsRect();
+    QPainter p(this);
 
     unsigned cidx = 0;
     int ncol = mCount;
-    QColor col = colorGroup().foreground();
+    QColor col = palette().foreground().color();
    
     if ( !mCRanges.isEmpty() )
     {
         col = mCRanges.at( cidx )->mColor;
         ncol = mCRanges.at( cidx )->mValue;
     }
-    p->setBrush( col );
-    p->setPen( col );
+    p.setBrush( col );
+    p.setPen( col );
 
     int lw = b.width() / mCount;
     int lx = b.left() + 1;
@@ -138,21 +147,22 @@ void KALedMeter::drawContents( QPainter *p )
             {
                 col = mCRanges.at( cidx )->mColor;
                 ncol = mCRanges.at( cidx )->mValue;
-                p->setBrush( col );
-                p->setPen( col );
+                p.setBrush( col );
+                p.setPen( col );
             }
         }
 
-        p->drawRect( lx, b.top() + 1, lw - 1, b.height() - 2 );
+        p.drawRect( lx, b.top() + 1, lw - 1, b.height() - 2 );
     }
 }
 
 void KALedMeter::calcColorRanges()
 {
     int prev = 0;
-    ColorRange *cr;
-    for ( cr = mCRanges.first(); cr; cr = mCRanges.next() )
+
+    for(QList<ColorRange*>::iterator it = mCRanges.begin(); it != mCRanges.end(); it++)
     {
+        ColorRange *cr = *it;
         cr->mValue = prev + cr->mPc * mCount / 100;
         prev = cr->mValue;
     }
